@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,24 +17,35 @@
 
 #include "LIEF/MachO/Binary.h"
 #include "LIEF/MachO/Parser.hpp"
+#include "LIEF/MachO/FatBinary.hpp"
 
 #include "Binary.hpp"
 
 using namespace LIEF::MachO;
 
 Macho_Binary_t** macho_parse(const char *file) {
-  FatBinary* macho_binaries = Parser::parse(file).release();
-
-  Macho_Binary_t** c_macho_binaries = static_cast<Macho_Binary_t**>(
-      malloc((macho_binaries->size() + 1) * sizeof(Macho_Binary_t**)));
-
-  for (size_t i = 0; i < macho_binaries->size(); ++i) {
-    Binary& binary = (*macho_binaries)[i];
-    c_macho_binaries[i] = static_cast<Macho_Binary_t*>(malloc(sizeof(Macho_Binary_t)));
-    init_c_binary(c_macho_binaries[i], &binary);
+  FatBinary* fat = Parser::parse(file).release();
+  if (fat == nullptr) {
+    return nullptr;
   }
 
-  c_macho_binaries[macho_binaries->size()] = nullptr;
+  size_t nb_bin = fat->size();
+
+  auto** c_macho_binaries = static_cast<Macho_Binary_t**>(
+      malloc((fat->size() + 1) * sizeof(Macho_Binary_t**)));
+
+  for (size_t i = 0; i < nb_bin; ++i) {
+    Binary* binary = fat->at(i);
+    if (binary != nullptr) {
+      c_macho_binaries[i] = static_cast<Macho_Binary_t*>(malloc(sizeof(Macho_Binary_t)));
+      init_c_binary(c_macho_binaries[i], binary);
+    }
+  }
+
+  fat->release_all_binaries();
+
+  c_macho_binaries[nb_bin] = nullptr;
+  delete fat;
 
   return c_macho_binaries;
 }
