@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,20 +23,16 @@ using namespace LIEF::ART;
 
 
 int main(int argc, char **argv) {
-  LIEF::Logger::set_level(LIEF::LOGGING_LEVEL::LOG_DEBUG);
+  LIEF::logging::set_level(LIEF::logging::LEVEL::DEBUG);
   if (argc != 2) {
-    std::cerr << "Usage: " << argv[0] << " <ART file>" << std::endl;
+    std::cerr << "Usage: " << argv[0] << " <ART file>" << '\n';
     return EXIT_FAILURE;
   }
-
-  std::unique_ptr<const File> file;
-
-  try {
-    file = std::unique_ptr<const File>{LIEF::ART::Parser::parse(argv[1])};
-  } catch (const LIEF::exception& e) {
-    std::cerr << e.what() << std::endl;
-    return EXIT_FAILURE;
+  if (std::unique_ptr<const File> file = LIEF::ART::Parser::parse(argv[1])) {
+    std::cout << *file << "\n";
+    return EXIT_SUCCESS;
   }
 
+  return EXIT_FAILURE;
 }
 
