@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,23 +23,19 @@ using namespace LIEF::VDEX;
 
 
 int main(int argc, char **argv) {
-  LIEF::Logger::set_level(LIEF::LOGGING_LEVEL::LOG_DEBUG);
+  LIEF::logging::set_level(LIEF::logging::LEVEL::DEBUG);
   if (argc != 2) {
-    std::cerr << "Usage: " << argv[0] << " <VDEX file>" << std::endl;
+    std::cerr << "Usage: " << argv[0] << " <VDEX file>" << '\n';
     return EXIT_FAILURE;
   }
 
-  std::unique_ptr<const File> file;
 
-  try {
-    file = std::unique_ptr<const File>{LIEF::VDEX::Parser::parse(argv[1])};
-    for (auto&& f : file->dex_files()) {
-      std::cout << f.location() << std::endl;
+  if (const auto file = LIEF::VDEX::Parser::parse(argv[1])) {
+    for (const auto& f : file->dex_files()) {
+      std::cout << f.location() << '\n';
     }
-  } catch (const LIEF::exception& e) {
-    std::cerr << e.what() << std::endl;
-    return EXIT_FAILURE;
+    return EXIT_SUCCESS;
   }
-
+  return EXIT_FAILURE;
 }
 
