@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,31 +13,35 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIEF_ABSTRACT_HASH_H_
-#define LIEF_ABSTRACT_HASH_H_
+#ifndef LIEF_ABSTRACT_HASH_H
+#define LIEF_ABSTRACT_HASH_H
 
 #include "LIEF/visibility.h"
 #include "LIEF/hash.hpp"
-#include "LIEF/Abstract.hpp"
 
 namespace LIEF {
+class Binary;
+class Header;
+class Relocation;
+class Object;
 
 class LIEF_API AbstractHash : public LIEF::Hash {
   public:
-  static size_t hash(const Object& obj);
+  static LIEF::Hash::value_type hash(const Object& obj);
 
   public:
   using LIEF::Hash::Hash;
   using LIEF::Hash::visit;
 
   public:
-  virtual void visit(const Binary& binary)         override;
-  virtual void visit(const Header& header)         override;
-  virtual void visit(const Section& section)       override;
-  virtual void visit(const Symbol& symbol)         override;
-  virtual void visit(const Relocation& relocation) override;
+  void visit(const Binary& binary)         override;
+  void visit(const Header& header)         override;
+  void visit(const Section& section)       override;
+  void visit(const Symbol& symbol)         override;
+  void visit(const Relocation& relocation) override;
+  void visit(const Function& function)     override;
 
-  virtual ~AbstractHash(void);
+  ~AbstractHash() override;
 };
 
 }
