@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,18 +13,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIEF_DEX_H_
-#define LIEF_DEX_H_
+#ifndef LIEF_DEX_H
+#define LIEF_DEX_H
 #include "LIEF/config.h"
 
 #if defined(LIEF_DEX_SUPPORT)
 #include "LIEF/DEX/Parser.hpp"
 #include "LIEF/DEX/utils.hpp"
 #include "LIEF/DEX/File.hpp"
-#include "LIEF/DEX/Structures.hpp"
 #include "LIEF/DEX/Class.hpp"
+#include "LIEF/DEX/Prototype.hpp"
 #include "LIEF/DEX/Header.hpp"
 #include "LIEF/DEX/Method.hpp"
+#include "LIEF/DEX/Field.hpp"
+#include "LIEF/DEX/EnumToString.hpp"
 #endif
 
 #endif
