@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2023 R. Thomas
- * Copyright 2017 - 2023 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,8 +20,6 @@
 #pragma message("LIEF will disable #define enums. Please use LIEF_ELF_XXXX or LIEF::ELF::XXXX instead!")
 #endif
 
-
-
 #undef EI_MAG0
 #undef EI_MAG1
 #undef EI_MAG2
@@ -232,6 +230,7 @@
 #undef EM_AMDGPU
 #undef EM_RISCV
 #undef EM_BPF
+#undef EM_LOONGARCH
 
 
 #undef ELFCLASSNONE
@@ -348,6 +347,11 @@
 #undef EF_HEXAGON_ISA_V5
 
 
+#undef EF_LOONGARCH_ABI_SOFT_FLOAT
+#undef EF_LOONGARCH_ABI_SINGLE_FLOAT
+#undef EF_LOONGARCH_ABI_DOUBLE_FLOAT
+
+
 #undef SHN_UNDEF
 #undef SHN_LORESERVE
 #undef SHN_LOPROC
@@ -640,6 +644,7 @@
 #undef DF_1_SYMINTPOSE
 #undef DF_1_GLOBAUDIT
 #undef DF_1_SINGLETON
+#undef DF_1_PIE
 
 #undef RHF_NONE
 #undef RHF_QUICKSTART
@@ -677,6 +682,15 @@
 #undef COUNT_HASH
 #undef COUNT_RELOCATIONS
 
+#undef NT_ARM_VFP
+#undef NT_ARM_TLS
+#undef NT_ARM_HW_BREAK
+#undef NT_ARM_HW_WATCH
+#undef NT_ARM_SYSTEM_CALL
+#undef NT_ARM_SVE
+
+#undef NT_386_TLS
+#undef NT_386_IOPERM
 
 #undef NT_UNKNOWN
 #undef NT_GNU_ABI_TAG
@@ -1576,6 +1590,95 @@
 #undef R_X86_64_GOTPCRELX
 #undef R_X86_64_REX_GOTPCRELX
 
+#undef R_LARCH_NONE
+#undef R_LARCH_32
+#undef R_LARCH_64
+#undef R_LARCH_RELATIVE
+#undef R_LARCH_COPY
+#undef R_LARCH_JUMP_SLOT
+#undef R_LARCH_TLS_DTPMOD32
+#undef R_LARCH_TLS_DTPMOD64
+#undef R_LARCH_TLS_DTPREL32
+#undef R_LARCH_TLS_DTPREL64
+#undef R_LARCH_TLS_TPREL32
+#undef R_LARCH_TLS_TPREL64
+#undef R_LARCH_IRELATIVE
+#undef R_LARCH_MARK_LA
+#undef R_LARCH_MARK_PCREL
+#undef R_LARCH_SOP_PUSH_PCREL
+#undef R_LARCH_SOP_PUSH_ABSOLUTE
+#undef R_LARCH_SOP_PUSH_DUP
+#undef R_LARCH_SOP_PUSH_GPREL
+#undef R_LARCH_SOP_PUSH_TLS_TPREL
+#undef R_LARCH_SOP_PUSH_TLS_GOT
+#undef R_LARCH_SOP_PUSH_TLS_GD
+#undef R_LARCH_SOP_PUSH_PLT_PCREL
+#undef R_LARCH_SOP_ASSERT
+#undef R_LARCH_SOP_NOT
+#undef R_LARCH_SOP_SUB
+#undef R_LARCH_SOP_SL
+#undef R_LARCH_SOP_SR
+#undef R_LARCH_SOP_ADD
+#undef R_LARCH_SOP_AND
+#undef R_LARCH_SOP_IF_ELSE
+#undef R_LARCH_SOP_POP_32_S_10_5
+#undef R_LARCH_SOP_POP_32_U_10_12
+#undef R_LARCH_SOP_POP_32_S_10_12
+#undef R_LARCH_SOP_POP_32_S_10_16
+#undef R_LARCH_SOP_POP_32_S_10_16_S2
+#undef R_LARCH_SOP_POP_32_S_5_20
+#undef R_LARCH_SOP_POP_32_S_0_5_10_16_S2
+#undef R_LARCH_SOP_POP_32_S_0_10_10_16_S2
+#undef R_LARCH_SOP_POP_32_U
+#undef R_LARCH_ADD8
+#undef R_LARCH_ADD16
+#undef R_LARCH_ADD24
+#undef R_LARCH_ADD32
+#undef R_LARCH_ADD64
+#undef R_LARCH_SUB8
+#undef R_LARCH_SUB16
+#undef R_LARCH_SUB24
+#undef R_LARCH_SUB32
+#undef R_LARCH_SUB64
+#undef R_LARCH_GNU_VTINHERIT
+#undef R_LARCH_GNU_VTENTRY
+#undef R_LARCH_B16
+#undef R_LARCH_B21
+#undef R_LARCH_B26
+#undef R_LARCH_ABS_HI20
+#undef R_LARCH_ABS_LO12
+#undef R_LARCH_ABS64_LO20
+#undef R_LARCH_ABS64_HI12
+#undef R_LARCH_PCALA_HI20
+#undef R_LARCH_PCALA_LO12
+#undef R_LARCH_PCALA64_LO20
+#undef R_LARCH_PCALA64_HI12
+#undef R_LARCH_GOT_PC_HI20
+#undef R_LARCH_GOT_PC_LO12
+#undef R_LARCH_GOT64_PC_LO20
+#undef R_LARCH_GOT64_PC_HI12
+#undef R_LARCH_GOT_HI20
+#undef R_LARCH_GOT_LO12
+#undef R_LARCH_GOT64_LO20
+#undef R_LARCH_GOT64_HI12
+#undef R_LARCH_TLS_LE_HI20
+#undef R_LARCH_TLS_LE_LO12
+#undef R_LARCH_TLS_LE64_LO20
+#undef R_LARCH_TLS_LE64_HI12
+#undef R_LARCH_TLS_IE_PC_HI20
+#undef R_LARCH_TLS_IE_PC_LO12
+#undef R_LARCH_TLS_IE64_PC_LO20
+#undef R_LARCH_TLS_IE64_PC_HI12
+#undef R_LARCH_TLS_IE_HI20
+#undef R_LARCH_TLS_IE_LO12
+#undef R_LARCH_TLS_IE64_LO20
+#undef R_LARCH_TLS_IE64_HI12
+#undef R_LARCH_TLS_LD_PC_HI20
+#undef R_LARCH_TLS_LD_HI20
+#undef R_LARCH_TLS_GD_PC_HI20
+#undef R_LARCH_TLS_GD_HI20
+#undef R_LARCH_32_PCREL
+#undef R_LARCH_RELAX
 
 #undef AT_NULL
 #undef AT_IGNORE
