@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,8 +13,8 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIEF_OAT_H_
-#define LIEF_OAT_H_
+#ifndef LIEF_OAT_H
+#define LIEF_OAT_H
 
 #include "LIEF/config.h"
 
@@ -26,6 +26,7 @@
 #include "LIEF/OAT/DexFile.hpp"
 #include "LIEF/OAT/Class.hpp"
 #include "LIEF/OAT/Method.hpp"
+#include "LIEF/OAT/EnumToString.hpp"
 #endif
 
 #endif
