@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,32 +13,38 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIEF_OAT_HASH_H_
-#define LIEF_OAT_HASH_H_
+#ifndef LIEF_OAT_HASH_H
+#define LIEF_OAT_HASH_H
 
 #include "LIEF/visibility.h"
 #include "LIEF/hash.hpp"
-#include "LIEF/OAT.hpp"
 
 namespace LIEF {
+class Object;
 namespace OAT {
 
+class Binary;
+class Class;
+class DexFile;
+class Header;
+class Method;
+
 class LIEF_API Hash : public LIEF::Hash {
   public:
-  static size_t hash(const Object& obj);
+  static LIEF::Hash::value_type hash(const Object& obj);
 
   public:
   using LIEF::Hash::Hash;
   using LIEF::Hash::visit;
 
   public:
-  virtual void visit(const Binary& binary)        override;
-  virtual void visit(const Header& header)        override;
-  virtual void visit(const DexFile& dex_file)     override;
-  virtual void visit(const Class& cls)            override;
-  virtual void visit(const Method& method)        override;
+  void visit(const Binary& binary)        override;
+  void visit(const Header& header)        override;
+  void visit(const DexFile& dex_file)     override;
+  void visit(const Class& cls)            override;
+  void visit(const Method& method)        override;
 
-  virtual ~Hash(void);
+  ~Hash() override;
 };
 
 }
