@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,20 +16,39 @@
 #ifndef LIEF_PE_ENUM_TO_STRING_H
 #define LIEF_PE_ENUM_TO_STRING_H
 
+#include <cstdint>
+#include <cstddef>
+
 #include "LIEF/visibility.h"
-#include "LIEF/PE/Structures.hpp"
 
 namespace LIEF {
 namespace PE {
+
+enum SYMBOL_SECTION_NUMBER : int;
+enum SYMBOL_STORAGE_CLASS : int;
+enum class ACCELERATOR_FLAGS : size_t;
+enum class ACCELERATOR_VK_CODES : size_t;
+enum class ALGORITHMS : uint32_t;
+enum class CODE_PAGES : size_t;
+enum class DIALOG_BOX_STYLES : size_t;
+enum class EXTENDED_WINDOW_STYLES : size_t;
+enum class FIXED_VERSION_FILE_FLAGS : size_t;
+enum class FIXED_VERSION_FILE_SUB_TYPES : size_t;
+enum class FIXED_VERSION_FILE_TYPES : size_t;
+enum class FIXED_VERSION_OS : size_t;
+enum class PE_SECTION_TYPES : uint8_t;
+enum class PE_TYPE : uint16_t;
+enum class RELOCATIONS_AMD64 : size_t;
+enum class RELOCATIONS_ARM : size_t;
+enum class RELOCATIONS_BASE_TYPES : size_t;
+enum class RELOCATIONS_I386 : size_t;
+enum class SUBSYSTEM : size_t;
+enum class SYMBOL_BASE_TYPES : size_t;
+enum class SYMBOL_COMPLEX_TYPES : size_t;
+enum class WINDOW_STYLES : size_t;
+
 LIEF_API const char* to_string(PE_TYPE e);
-LIEF_API const char* to_string(DATA_DIRECTORY e);
 
-LIEF_API const char* to_string(MACHINE_TYPES e);
-LIEF_API const char* to_string(HEADER_CHARACTERISTICS e);
-LIEF_API const char* to_string(SUBSYSTEM e);
-LIEF_API const char* to_string(DLL_CHARACTERISTICS e);
-
-LIEF_API const char* to_string(SECTION_CHARACTERISTICS e);
 LIEF_API const char* to_string(PE_SECTION_TYPES e);
 
 LIEF_API const char* to_string(SYMBOL_BASE_TYPES e);
@@ -42,12 +61,6 @@ LIEF_API const char* to_string(RELOCATIONS_I386 e);
 LIEF_API const char* to_string(RELOCATIONS_AMD64 e);
 LIEF_API const char* to_string(RELOCATIONS_ARM e);
 
-LIEF_API const char* to_string(DEBUG_TYPES e);
-LIEF_API const char* to_string(CODE_VIEW_SIGNATURES e);
-
-LIEF_API const char* to_string(RESOURCE_TYPES e);
-LIEF_API const char* to_string(RESOURCE_LANGS e);
-LIEF_API const char* to_string(RESOURCE_SUBLANGS e);
 LIEF_API const char* to_string(CODE_PAGES e);
 
 LIEF_API const char* to_string(EXTENDED_WINDOW_STYLES e);
@@ -59,10 +72,10 @@ LIEF_API const char* to_string(FIXED_VERSION_FILE_FLAGS e);
 LIEF_API const char* to_string(FIXED_VERSION_FILE_TYPES e);
 LIEF_API const char* to_string(FIXED_VERSION_FILE_SUB_TYPES e);
 
-LIEF_API const char* to_string(WIN_VERSION e);
+LIEF_API const char* to_string(ACCELERATOR_FLAGS e);
+LIEF_API const char* to_string(ACCELERATOR_VK_CODES e);
 
-LIEF_API const char* to_string(GUARD_CF_FLAGS e);
-LIEF_API const char* to_string(GUARD_RF_FLAGS e);
+LIEF_API const char* to_string(ALGORITHMS e);
 
 } // namespace PE
 } // namespace LIEF
