@@ -1,5 +1,6 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
+ * Copyright 2017 - 2021 K. Nakagawa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,8 +14,8 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIEF_PE_UNDEF_H_
-#define LIEF_PE_UNDEF_H_
+#if !defined(LIEF_PE_UNDEF_H) || defined(LIEF_PE_FORCE_UNDEF)
+#define LIEF_PE_UNDEF_H
 
 #ifdef IMAGE_FILE_MACHINE_UNKNOWN
 #pragma message("LIEF will disable #define enums. Please use LIEF_PE_XXXX or LIEF::PE::XXXX instead!")
@@ -35,6 +36,7 @@
 #undef IMAGE_FILE_MACHINE_MIPSFPU16
 #undef IMAGE_FILE_MACHINE_POWERPC
 #undef IMAGE_FILE_MACHINE_POWERPCFP
+#undef IMAGE_FILE_MACHINE_POWERPCBE
 #undef IMAGE_FILE_MACHINE_R4000
 #undef IMAGE_FILE_MACHINE_RISCV32
 #undef IMAGE_FILE_MACHINE_RISCV64
@@ -145,6 +147,13 @@
 #undef IMAGE_REL_I386_TOKEN
 #undef IMAGE_REL_I386_SECREL7
 #undef IMAGE_REL_I386_REL32
+#undef IMAGE_REL_BASED_ARM_MOV32A
+#undef IMAGE_REL_BASED_ARM_MOV32
+#undef IMAGE_REL_BASED_RISCV_HI20
+#undef IMAGE_REL_BASED_ARM_MOV32T
+#undef IMAGE_REL_BASED_THUMB_MOV32
+#undef IMAGE_REL_BASED_RISCV_LOW12I
+#undef IMAGE_REL_BASED_RISCV_LOW12S
 
 #undef IMAGE_REL_AMD64_ABSOLUTE
 #undef IMAGE_REL_AMD64_ADDR64
@@ -242,12 +251,14 @@
 #undef IMAGE_DEBUG_TYPE_OMAP_TO_SRC
 #undef IMAGE_DEBUG_TYPE_OMAP_FROM_SRC
 #undef IMAGE_DEBUG_TYPE_BORLAND
+#undef IMAGE_DEBUG_TYPE_RESERVED10
 #undef IMAGE_DEBUG_TYPE_CLSID
 #undef IMAGE_DEBUG_TYPE_VC_FEATURE
 #undef IMAGE_DEBUG_TYPE_POGO
 #undef IMAGE_DEBUG_TYPE_ILTCG
 #undef IMAGE_DEBUG_TYPE_MPX
 #undef IMAGE_DEBUG_TYPE_REPRO
+#undef IMAGE_DEBUG_TYPE_EX_DLLCHARACTERISTICS
 
 #undef IMAGE_SCN_TYPE_NO_PAD
 #undef IMAGE_SCN_CNT_CODE
@@ -285,7 +296,6 @@
 #undef IMAGE_SCN_MEM_READ
 #undef IMAGE_SCN_MEM_WRITE
 
-#undef RESOURCE_TYPES
 #undef RESOURCE_LANGS
 
 
@@ -731,6 +741,186 @@
 #undef VFT2_FONT_VECTOR
 #undef VFT2_UNKNOWN
 
+#undef FVIRTKEY
+#undef FNOINVERT
+#undef FSHIFT
+#undef FCONTROL
+#undef FALT
+#undef END
 
+#undef VK_LBUTTON
+#undef VK_RBUTTON
+#undef VK_CANCEL
+#undef VK_MBUTTON
+#undef VK_XBUTTON1
+#undef VK_XBUTTON2
+#undef VK_BACK
+#undef VK_TAB
+#undef VK_CLEAR
+#undef VK_RETURN
+#undef VK_SHIFT
+#undef VK_CONTROL
+#undef VK_MENU
+#undef VK_PAUSE
+#undef VK_CAPITAL
+#undef VK_KANA
+#undef VK_HANGUEL
+#undef VK_HANGUL
+#undef VK_IME_ON
+#undef VK_JUNJA
+#undef VK_FINAL
+#undef VK_HANJA
+#undef VK_KANJI
+#undef VK_IME_OFF
+#undef VK_ESCAPE
+#undef VK_CONVERT
+#undef VK_NONCONVERT
+#undef VK_ACCEPT
+#undef VK_MODECHANGE
+#undef VK_SPACE
+#undef VK_PRIOR
+#undef VK_NEXT
+#undef VK_END
+#undef VK_HOME
+#undef VK_LEFT
+#undef VK_UP
+#undef VK_RIGHT
+#undef VK_DOWN
+#undef VK_SELECT
+#undef VK_PRINT
+#undef VK_EXECUTE
+#undef VK_SNAPSHOT
+#undef VK_INSERT
+#undef VK_DELETE
+#undef VK_HELP
+#undef VK_0
+#undef VK_1
+#undef VK_2
+#undef VK_3
+#undef VK_4
+#undef VK_5
+#undef VK_6
+#undef VK_7
+#undef VK_8
+#undef VK_9
+#undef VK_A
+#undef VK_B
+#undef VK_C
+#undef VK_D
+#undef VK_E
+#undef VK_F
+#undef VK_G
+#undef VK_H
+#undef VK_I
+#undef VK_J
+#undef VK_K
+#undef VK_L
+#undef VK_M
+#undef VK_N
+#undef VK_O
+#undef VK_P
+#undef VK_Q
+#undef VK_R
+#undef VK_S
+#undef VK_T
+#undef VK_U
+#undef VK_V
+#undef VK_W
+#undef VK_X
+#undef VK_Y
+#undef VK_Z
+#undef VK_LWIN
+#undef VK_RWIN
+#undef VK_APPS
+#undef VK_SLEEP
+#undef VK_NUMPAD0
+#undef VK_NUMPAD1
+#undef VK_NUMPAD2
+#undef VK_NUMPAD3
+#undef VK_NUMPAD4
+#undef VK_NUMPAD5
+#undef VK_NUMPAD6
+#undef VK_NUMPAD7
+#undef VK_NUMPAD8
+#undef VK_NUMPAD9
+#undef VK_MULTIPLY
+#undef VK_ADD
+#undef VK_SEPARATOR
+#undef VK_SUBTRACT
+#undef VK_DECIMAL
+#undef VK_DIVIDE
+#undef VK_F1
+#undef VK_F2
+#undef VK_F3
+#undef VK_F4
+#undef VK_F5
+#undef VK_F6
+#undef VK_F7
+#undef VK_F8
+#undef VK_F9
+#undef VK_F10
+#undef VK_F11
+#undef VK_F12
+#undef VK_F13
+#undef VK_F14
+#undef VK_F15
+#undef VK_F16
+#undef VK_F17
+#undef VK_F18
+#undef VK_F19
+#undef VK_F20
+#undef VK_F21
+#undef VK_F22
+#undef VK_F23
+#undef VK_F24
+#undef VK_NUMLOCK
+#undef VK_SCROLL
+#undef VK_LSHIFT
+#undef VK_RSHIFT
+#undef VK_LCONTROL
+#undef VK_RCONTROL
+#undef VK_LMENU
+#undef VK_RMENU
+#undef VK_BROWSER_BACK
+#undef VK_BROWSER_FORWARD
+#undef VK_BROWSER_REFRESH
+#undef VK_BROWSER_STOP
+#undef VK_BROWSER_SEARCH
+#undef VK_BROWSER_FAVORITES
+#undef VK_BROWSER_HOME
+#undef VK_VOLUME_MUTE
+#undef VK_VOLUME_DOWN
+#undef VK_VOLUME_UP
+#undef VK_MEDIA_NEXT_TRACK
+#undef VK_MEDIA_PREV_TRACK
+#undef VK_MEDIA_STOP
+#undef VK_MEDIA_PLAY_PAUSE
+#undef VK_LAUNCH_MAIL
+#undef VK_LAUNCH_MEDIA_SELECT
+#undef VK_LAUNCH_APP1
+#undef VK_LAUNCH_APP2
+#undef VK_OEM_1
+#undef VK_OEM_PLUS
+#undef VK_OEM_COMMA
+#undef VK_OEM_MINUS
+#undef VK_OEM_PERIOD
+#undef VK_OEM_2
+#undef VK_OEM_4
+#undef VK_OEM_5
+#undef VK_OEM_6
+#undef VK_OEM_7
+#undef VK_OEM_8
+#undef VK_OEM_102
+#undef VK_PROCESSKEY
+#undef VK_PACKET
+#undef VK_ATTN
+#undef VK_CRSEL
+#undef VK_EXSEL
+#undef VK_EREOF
+#undef VK_PLAY
+#undef VK_ZOOM
+#undef VK_NONAME
+#undef VK_PA1
+#undef VK_OEM_CLEAR
 
 #endif
