@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,12 +13,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIEF_VDEX_H_
-#define LIEF_VDEX_H_
+#ifndef LIEF_VDEX_H
+#define LIEF_VDEX_H
 
 #include "LIEF/config.h"
 
 #if defined(LIEF_VDEX_SUPPORT)
+#if !defined(LIEF_DEX_SUPPORT)
+#error "The VDEX module can't be used without the DEX support"
+#endif
+#include "LIEF/DEX.hpp"
 #include "LIEF/VDEX/Parser.hpp"
 #include "LIEF/VDEX/utils.hpp"
 #include "LIEF/VDEX/File.hpp"
