@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,18 +13,22 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIEF_VDEX_TYPE_TRAITS_H_
-#define LIEF_VDEX_TYPE_TRAITS_H_
-
-#include <vector>
-#include "LIEF/iterators.hpp"
-#include "LIEF/OAT.hpp"
+#ifndef LIEF_VDEX_TYPE_TRAITS_H
+#define LIEF_VDEX_TYPE_TRAITS_H
+#include <cstdint>
+#include <unordered_map>
+#include <LIEF/DEX/deopt.hpp>
 
 namespace LIEF {
+namespace DEX {
+class File;
+} // namespace DEX
+
 namespace VDEX {
 using vdex_version_t = uint32_t;
-using dex2dex_info_t = LIEF::OAT::dex2dex_info_t;
-}
-}
+using dex2dex_info_t = std::unordered_map<const DEX::File*, DEX::dex2dex_info_t>;
+} // namespace VDEX
+} // namespace LIEF
+
 
 #endif
