@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,16 +21,13 @@
 namespace LIEF {
 namespace ART {
 
-File::File(void) :
-  header_{}
-{}
+File::File() = default;
 
-
-const Header& File::header(void) const {
-  return this->header_;
+const Header& File::header() const {
+  return header_;
 }
 
-Header& File::header(void) {
+Header& File::header() {
   return const_cast<Header&>(static_cast<const File*>(this)->header());
 }
 
@@ -38,18 +35,10 @@ void File::accept(Visitor& visitor) const {
   visitor.visit(*this);
 }
 
-bool File::operator==(const File& rhs) const {
-  size_t hash_lhs = Hash::hash(*this);
-  size_t hash_rhs = Hash::hash(rhs);
-  return hash_lhs == hash_rhs;
-}
-
-bool File::operator!=(const File& rhs) const {
-  return not (*this == rhs);
-}
 
 
-File::~File(void) = default;
+
+File::~File() = default;
 
 std::ostream& operator<<(std::ostream& os, const File& art_file) {
   os << art_file.header();
