@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,12 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#include "LIEF/logging++.hpp"
+#include "logging.hpp"
 
 #include "LIEF/DEX/instructions.hpp"
 
 #include <algorithm>
-#include <iostream>
 #include <map>
 
 namespace LIEF {
@@ -275,14 +274,14 @@ INST_FORMATS inst_format_from_opcode(OPCODES op) {
 
   auto   it  = size_map.find(op);
   //if (it == std::end(size_map)) {
-  //  std::cout << std::hex << "OP: " << op << std::endl;
+  //  std::cout << std::hex << "OP: " << op << '\n';
   //}
   return it == size_map.end() ? INST_FORMATS::F_00x : it->second;
 }
 
 size_t inst_size_from_format(INST_FORMATS fmt) {
   static const std::map<INST_FORMATS, size_t> size_map {
-    { INST_FORMATS::F_00x,   -1u  },
+    { INST_FORMATS::F_00x,   SIZE_MAX  },
     { INST_FORMATS::F_10x,   2    },
     { INST_FORMATS::F_12x,   2    },
     { INST_FORMATS::F_11n,   2    },
@@ -326,10 +325,6 @@ size_t inst_size_from_opcode(OPCODES op) {
 }
 
 bool is_switch_array(const uint8_t* ptr, const uint8_t* end) {
-  CHECK_NE(ptr, nullptr);
-  CHECK_NE(end, nullptr);
-  CHECK_LE(ptr, end);
-
   const size_t size = end - ptr;
   const size_t underlying_struct_size = std::min({
       sizeof(packed_switch),
@@ -340,17 +335,17 @@ bool is_switch_array(const uint8_t* ptr, const uint8_t* end) {
     return false;
   }
 
-  const OPCODES opcode = static_cast<OPCODES>(*ptr);
+  const auto opcode = static_cast<OPCODES>(*ptr);
   const bool valid_opcode =
-    opcode == OPCODES::OP_NOP or
-    opcode == OPCODES::OP_RETURN_VOID or
+    opcode == OPCODES::OP_NOP ||
+    opcode == OPCODES::OP_RETURN_VOID ||
     opcode == OPCODES::OP_RETURN_VOID_NO_BARRIER;
 
-  if (not valid_opcode) {
+  if (!valid_opcode) {
     return false;
   }
 
-  const SWITCH_ARRAY_IDENT ident = static_cast<SWITCH_ARRAY_IDENT>(static_cast<uint16_t>(ptr[1] << 8) | opcode);
+  const auto ident = static_cast<SWITCH_ARRAY_IDENT>(static_cast<uint16_t>(ptr[1] << 8) | opcode);
 
   switch(ident) {
     case SWITCH_ARRAY_IDENT::IDENT_PACKED_SWITCH:
@@ -368,12 +363,12 @@ bool is_switch_array(const uint8_t* ptr, const uint8_t* end) {
 }
 
 size_t switch_array_size(const uint8_t* ptr, const uint8_t* end) {
-  if (not is_switch_array(ptr, end)) {
-    return -1u;
+  if (!is_switch_array(ptr, end)) {
+    return SIZE_MAX;
   }
 
-  const OPCODES opcode = static_cast<OPCODES>(*ptr);
-  const SWITCH_ARRAY_IDENT ident = static_cast<SWITCH_ARRAY_IDENT>(static_cast<uint16_t>(ptr[1] << 8) | opcode);
+  const auto opcode = static_cast<OPCODES>(*ptr);
+  const auto ident = static_cast<SWITCH_ARRAY_IDENT>(static_cast<uint16_t>(ptr[1] << 8) | opcode);
   const uint8_t* ptr_struct = ptr;
   size_t size = 0;
 
@@ -405,7 +400,7 @@ size_t switch_array_size(const uint8_t* ptr, const uint8_t* end) {
       }
     default:
       {
-        return -1u;
+        return SIZE_MAX;
       }
   }
 
