@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,50 +14,25 @@
  * limitations under the License.
  */
 #include "LIEF/ELF/DynamicEntryLibrary.hpp"
+#include "LIEF/Visitor.hpp"
 
-#include <iomanip>
+#include <spdlog/fmt/fmt.h>
 
 namespace LIEF {
 namespace ELF {
 
-DynamicEntryLibrary& DynamicEntryLibrary::operator=(const DynamicEntryLibrary&) = default;
-DynamicEntryLibrary::DynamicEntryLibrary(const DynamicEntryLibrary&) = default;
-
-DynamicEntryLibrary::DynamicEntryLibrary(void) :
-  DynamicEntry::DynamicEntry{DYNAMIC_TAGS::DT_NEEDED, 0},
-  libname_{}
-{}
-
-DynamicEntryLibrary::DynamicEntryLibrary(const std::string& name) :
-  DynamicEntry::DynamicEntry{DYNAMIC_TAGS::DT_NEEDED, 0},
-  libname_{name}
-{}
-
-const std::string& DynamicEntryLibrary::name(void) const {
-  return this->libname_;
-}
-
-
-void DynamicEntryLibrary::name(const std::string& name) {
-  this->libname_ = name;
-}
-
-
 void DynamicEntryLibrary::accept(Visitor& visitor) const {
   visitor.visit(*this);
 }
 
 std::ostream& DynamicEntryLibrary::print(std::ostream& os) const {
-
   DynamicEntry::print(os);
-  os << std::hex
-     << std::left
-     << std::setw(10) << this->name();
+  os << fmt::format("{:<10}", name());
   return os;
+}
 
 }
 }
-}
 
 
 
