@@ -1,6 +1,6 @@
 
-/* Copyright 2017 - 2023 R. Thomas
- * Copyright 2017 - 2023 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,10 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIEF_ELF_SIZING_INFO_H_
-#define LIEF_ELF_SIZING_INFO_H_
+#ifndef LIEF_ELF_SIZING_INFO_H
+#define LIEF_ELF_SIZING_INFO_H
 #include "LIEF/visibility.h"
-#include "LIEF/types.hpp"
+
+#include <cstdint>
+
 namespace LIEF {
 namespace ELF {
 struct sizing_info_t {
@@ -28,6 +30,8 @@ struct sizing_info_t {
   uint64_t gnu_hash = 0;
   uint64_t hash = 0;
   uint64_t rela = 0;
+  uint64_t relr = 0;
+  uint64_t android_rela = 0;
   uint64_t jmprel = 0;
   uint64_t versym = 0;
   uint64_t verdef = 0;
