@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,48 +23,11 @@
 
 namespace LIEF {
 namespace ELF {
-SysvHash& SysvHash::operator=(const SysvHash&) = default;
-SysvHash::SysvHash(const SysvHash&)           = default;
-SysvHash::~SysvHash(void)                    = default;
-
-SysvHash::SysvHash(void) :
-  buckets_{},
-  chains_{}
-{}
-
-
-uint32_t SysvHash::nbucket(void) const {
-  return static_cast<uint32_t>(this->buckets_.size());
-}
-
-uint32_t SysvHash::nchain(void) const {
-  return static_cast<uint32_t>(this->chains_.size());
-}
-
-const std::vector<uint32_t>& SysvHash::buckets(void) const {
-  return this->buckets_;
-}
-
-const std::vector<uint32_t>& SysvHash::chains(void) const {
-  return this->chains_;
-}
-
-bool SysvHash::operator==(const SysvHash& rhs) const {
-  size_t hash_lhs = Hash::hash(*this);
-  size_t hash_rhs = Hash::hash(rhs);
-  return hash_lhs == hash_rhs;
-}
-
-bool SysvHash::operator!=(const SysvHash& rhs) const {
-  return not (*this == rhs);
-}
-
 
 void SysvHash::accept(Visitor& visitor) const {
   visitor.visit(*this);
 }
 
-
 std::ostream& operator<<(std::ostream& os, const SysvHash& sysvhash) {
   os << std::hex << std::left;
 
@@ -98,11 +61,11 @@ std::ostream& operator<<(std::ostream& os, const SysvHash& sysvhash) {
 
 
 
-  os << std::setw(33) << std::setfill(' ') << "Number of buckets:"  << sysvhash.nbucket() << std::endl;
-  os << std::setw(33) << std::setfill(' ') << "Buckets:"            << buckets_str        << std::endl;
+  os << std::setw(33) << std::setfill(' ') << "Number of buckets:"  << sysvhash.nbucket() << '\n';
+  os << std::setw(33) << std::setfill(' ') << "Buckets:"            << buckets_str        << '\n';
 
-  os << std::setw(33) << std::setfill(' ') << "Number of chains:"   << sysvhash.nchain() << std::endl;
-  os << std::setw(33) << std::setfill(' ') << "Chains:"             << chains_str        << std::endl;
+  os << std::setw(33) << std::setfill(' ') << "Number of chains:"   << sysvhash.nchain() << '\n';
+  os << std::setw(33) << std::setfill(' ') << "Chains:"             << chains_str        << '\n';
 
   return os;
 
