@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,20 +13,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#include <iomanip>
 #include <fstream>
 #include <iterator>
 #include <algorithm>
-#include <functional>
 #include <numeric>
 
-#include "LIEF/exception.hpp"
+#include "logging.hpp"
+
 
 #include "LIEF/PE/hash.hpp"
 
-#include "LIEF/PE/utils.hpp"
 #include "LIEF/utils.hpp"
 #include "LIEF/PE/EnumToString.hpp"
+#include "PE/Structures.hpp"
 
 #include "LIEF/PE/resources/ResourceDialogItem.hpp"
 
@@ -35,138 +34,120 @@ namespace PE {
 
 ResourceDialogItem::ResourceDialogItem(const ResourceDialogItem&) = default;
 ResourceDialogItem& ResourceDialogItem::operator=(const ResourceDialogItem&) = default;
-ResourceDialogItem::~ResourceDialogItem(void) = default;
+ResourceDialogItem::~ResourceDialogItem() = default;
 
-ResourceDialogItem::ResourceDialogItem(void) :
-  is_extended_{false},
-  help_id_{0},
-  ext_style_{0},
-  style_{0},
-  id_{0},
-  x_{0},
-  y_{0},
-  cx_{0},
-  cy_{0},
-  window_class_{},
-  title_{},
-  extra_count_{0}
-{}
+ResourceDialogItem::ResourceDialogItem() = default;
 
-
-ResourceDialogItem::ResourceDialogItem(const pe_dialog_item_template_ext *header) :
+ResourceDialogItem::ResourceDialogItem(const details::pe_dialog_item_template_ext& header) :
   is_extended_{true},
-  help_id_{header->help_id},
-  ext_style_{header->ext_style},
-  style_{header->style},
-  id_{header->id},
-  x_{header->x},
-  y_{header->y},
-  cx_{header->cx},
-  cy_{header->cy},
-  window_class_{},
-  title_{},
+  help_id_{header.help_id},
+  ext_style_{header.ext_style},
+  style_{header.style},
+  id_{header.id},
+  x_{header.x},
+  y_{header.y},
+  cx_{header.cx},
+  cy_{header.cy},
   extra_count_{0}
 {}
 
 
-ResourceDialogItem::ResourceDialogItem(const pe_dialog_item_template *header) :
+ResourceDialogItem::ResourceDialogItem(const details::pe_dialog_item_template& header) :
   is_extended_{false},
   help_id_{0},
-  ext_style_{header->ext_style},
-  style_{header->style},
-  id_{header->id},
-  x_{header->x},
-  y_{header->y},
-  cx_{header->cx},
-  cy_{header->cy},
-  window_class_{},
-  title_{},
+  ext_style_{header.ext_style},
+  style_{header.style},
+  id_{header.id},
+  x_{header.x},
+  y_{header.y},
+  cx_{header.cx},
+  cy_{header.cy},
   extra_count_{0}
 {}
 
 
-bool ResourceDialogItem::is_extended(void) const {
-  return this->is_extended_;
+bool ResourceDialogItem::is_extended() const {
+  return is_extended_;
 }
 
-uint32_t ResourceDialogItem::extended_style(void) const {
-  return this->ext_style_;
+uint32_t ResourceDialogItem::extended_style() const {
+  return ext_style_;
 }
 
-std::set<EXTENDED_WINDOW_STYLES> ResourceDialogItem::extended_style_list(void) const {
+std::set<EXTENDED_WINDOW_STYLES> ResourceDialogItem::extended_style_list() const {
   std::set<EXTENDED_WINDOW_STYLES> ext_styles;
   std::copy_if(
-      std::begin(extended_window_styles_array),
-      std::end(extended_window_styles_array),
+      std::begin(details::extended_window_styles_array),
+      std::end(details::extended_window_styles_array),
       std::inserter(ext_styles, std::begin(ext_styles)),
-      std::bind(&ResourceDialogItem::has_extended_style, this, std::placeholders::_1));
+      [this] (EXTENDED_WINDOW_STYLES f) { return has_extended_style(f); });
 
   return ext_styles;
 
 }
 
 bool ResourceDialogItem::has_extended_style(EXTENDED_WINDOW_STYLES style) const {
-  return (this->ext_style_ & static_cast<uint32_t>(style)) != 0;
+  return (ext_style_ & static_cast<uint32_t>(style)) != 0;
 }
 
-uint32_t ResourceDialogItem::style(void) const {
-  return this->style_;
+uint32_t ResourceDialogItem::style() const {
+  return style_;
 }
 
-std::set<WINDOW_STYLES> ResourceDialogItem::style_list(void) const {
+std::set<WINDOW_STYLES> ResourceDialogItem::style_list() const {
   std::set<WINDOW_STYLES> styles;
   std::copy_if(
-      std::begin(window_styles_array),
-      std::end(window_styles_array),
+      std::begin(details::window_styles_array),
+      std::end(details::window_styles_array),
       std::inserter(styles, std::begin(styles)),
-      std::bind(&ResourceDialogItem::has_style, this, std::placeholders::_1));
+      [this] (WINDOW_STYLES f) { return has_style(f); });
 
   return styles;
 }
 
 bool ResourceDialogItem::has_style(WINDOW_STYLES style) const {
-  return (this->style_ & static_cast<uint32_t>(style)) != 0;
+  return (style_ & static_cast<uint32_t>(style)) != 0;
 }
 
 
-int16_t ResourceDialogItem::x(void) const {
-  return this->x_;
+int16_t ResourceDialogItem::x() const {
+  return x_;
 }
 
-int16_t ResourceDialogItem::y(void) const {
-  return this->y_;
+int16_t ResourceDialogItem::y() const {
+  return y_;
 }
 
-int16_t ResourceDialogItem::cx(void) const {
-  return this->cx_;
+int16_t ResourceDialogItem::cx() const {
+  return cx_;
 }
 
-int16_t ResourceDialogItem::cy(void) const {
-  return this->cy_;
+int16_t ResourceDialogItem::cy() const {
+  return cy_;
 }
 
 
-uint32_t ResourceDialogItem::id(void) const {
-  return this->id_;
+uint32_t ResourceDialogItem::id() const {
+  return id_;
 }
 
 
 // Extended API
 // ============
-uint32_t ResourceDialogItem::help_id(void) const {
-  if (not this->is_extended()) {
-    throw not_found("This dialog is not an extended one");
+uint32_t ResourceDialogItem::help_id() const {
+  if (!is_extended()) {
+    LIEF_WARN("This dialog is not an extended one. DLGTEMPLATEEX.helpID does not exist");
   }
-  return this->help_id_;
+  return help_id_;
 }
 
 
-const std::u16string& ResourceDialogItem::title(void) const {
-  if (not this->is_extended()) {
-    throw not_found("This dialog is not an extended one");
+const std::u16string& ResourceDialogItem::title() const {
+  if (!is_extended()) {
+    LIEF_WARN("This dialog is not an extended one. DLGTEMPLATEEX.title does not exist");
   }
 
-  return this->title_;
+  return title_;
 }
 
 
@@ -174,15 +155,7 @@ void ResourceDialogItem::accept(Visitor& visitor) const {
   visitor.visit(*this);
 }
 
-bool ResourceDialogItem::operator==(const ResourceDialogItem& rhs) const {
-  size_t hash_lhs = Hash::hash(*this);
-  size_t hash_rhs = Hash::hash(rhs);
-  return hash_lhs == hash_rhs;
-}
 
-bool ResourceDialogItem::operator!=(const ResourceDialogItem& rhs) const {
-  return not (*this == rhs);
-}
 
 
 std::ostream& operator<<(std::ostream& os, const ResourceDialogItem& dialog_item) {
@@ -208,11 +181,11 @@ std::ostream& operator<<(std::ostream& os, const ResourceDialogItem& dialog_item
   }
   os << ", " << std::dec << dialog_item.id();
 
-  if (not styles_str.empty()) {
+  if (!styles_str.empty()) {
     os << ", " << styles_str;
   }
 
-  if (not ext_styles_str.empty()) {
+  if (!ext_styles_str.empty()) {
     os << ", " << ext_styles_str;
   }
 
