@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2024 R. Thomas
+ * Copyright 2017 - 2024 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,13 +15,14 @@
  */
 
 #include "LIEF/VDEX/hash.hpp"
-#include "LIEF/VDEX.hpp"
+#include "LIEF/VDEX/File.hpp"
 #include "LIEF/DEX/hash.hpp"
+#include "LIEF/DEX/File.hpp"
 
 namespace LIEF {
 namespace VDEX {
 
-Hash::~Hash(void) = default;
+Hash::~Hash() = default;
 
 size_t Hash::hash(const Object& obj) {
   return LIEF::Hash::hash<LIEF::VDEX::Hash>(obj);
@@ -29,19 +30,19 @@ size_t Hash::hash(const Object& obj) {
 
 
 void Hash::visit(const File& file) {
-  this->process(file.header());
+  process(file.header());
   for (const DEX::File& dexfile : file.dex_files()) {
-    this->process(DEX::Hash::hash(dexfile));
+    process(DEX::Hash::hash(dexfile));
   }
 }
 
 void Hash::visit(const Header& header) {
-  this->process(header.magic());
-  this->process(header.version());
-  this->process(header.nb_dex_files());
-  this->process(header.dex_size());
-  this->process(header.verifier_deps_size());
-  this->process(header.quickening_info_size());
+  process(header.magic());
+  process(header.version());
+  process(header.nb_dex_files());
+  process(header.dex_size());
+  process(header.verifier_deps_size());
+  process(header.quickening_info_size());
 }
 
 
